==> botkit-0.6.17.tgz: package/docs/readme.md <==
# Botkit Docs

All documentation for Botkit now lives at our official documentation site, [https://botkit.ai/docs](https://botkit.ai/docs)

* [Get Started](https://botkit.ai/getstarted.html)
* [Introduction](https://botkit.ai/docs/)
* [Core Features](https://botkit.ai/docs/core.html)
* [Botkit Studio API](https://botkit.ai/docs/readme-studio.html)
* Platforms
  * [Web and Apps](https://botkit.ai/docs/readme-web.html)
  * [Slack](https://botkit.ai/docs/readme-slack.html)
  * [Cisco Webex Teams (_formerly Spark_)](https://botkit.ai/docs/readme-ciscospark.html)
  * [Cisco Jabber](https://botkit.ai/docs/readme-ciscojabber.html)
  * [Microsoft Teams](https://botkit.ai/docs/readme-teams.html)
  * [Facebook Messenger](https://botkit.ai/docs/readme-facebook.html)
  * [Twilio SMS](https://botkit.ai/docs/readme-twiliosms.html)
  * [Twilio IPM](https://botkit.ai/docs/readme-twilioipm.html)
  * [Microsoft Bot Framework](https://botkit.ai/docs/readme-botframework.html)
  * [Google Hangouts Chat](https://botkit.ai/docs/google-hangouts-chat.html)
* [Extending Botkit with Plugins and Middleware](https://botkit.ai/docs/middleware.html)
  * [Message Pipeline](https://botkit.ai/docs/readme-pipeline.html)
  * [List of current plugins](https://botkit.ai/docs/readme-middlewares.html)
* [Storing Information](https://botkit.ai/docs/storage.html)
* [Logging](https://botkit.ai/docs/logging.html)
* Contributing to Botkit
  * [Contributing to Botkit Core](CONTRIBUTING.md)
  * [Building platform connectors](https://botkit.ai/docs/howto/build_connector.html)

==> botkit-0.7.6.tgz: package/docs/readme.md <==
# Botkit Docs

All documentation for Botkit now lives at our official documentation site, [https://botkit.ai/docs](https://botkit.ai/docs)

* [Get Started](https://botkit.ai/getstarted.html)
* [Introduction](https://botkit.ai/docs/)
* [Core Features](https://botkit.ai/docs/core.html)
* [Botkit Studio API](https://botkit.ai/docs/readme-studio.html)
* Platforms
  * [Web and Apps](https://botkit.ai/docs/readme-web.html)
  * [Slack](https://botkit.ai/docs/readme-slack.html)
  * [Cisco Webex Teams (_formerly Spark_)](https://botkit.ai/docs/readme-webex.html)
  * [Cisco Jabber](https://botkit.ai/docs/readme-ciscojabber.html)
  * [Microsoft Teams](https://botkit.ai/docs/readme-teams.html)
  * [Facebook Messenger](https://botkit.ai/docs/readme-facebook.html)
  * [Twilio SMS](https://botkit.ai/docs/readme-twiliosms.html)
  * [Twilio IPM](https://botkit.ai/docs/readme-twilioipm.html)
  * [Microsoft Bot Framework](https://botkit.ai/docs/readme-botframework.html)
  * [Google Hangouts Chat](https://botkit.ai/docs/google-hangouts-chat.html)
* [Extending Botkit with Plugins and Middleware](https://botkit.ai/docs/middleware.html)
  * [Message Pipeline](https://botkit.ai/docs/readme-pipeline.html)
  * [List of current plugins](https://botkit.ai/docs/readme-middlewares.html)
* [Storing Information](https://botkit.ai/docs/storage.html)
* [Logging](https://botkit.ai/docs/logging.html)
* Contributing to Botkit
  * [Contributing to Botkit Core](CONTRIBUTING.md)
  * [Building platform connectors](https://botkit.ai/docs/howto/build_connector.html)
